@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 67568 2011-04-21 23:19:00Z CJP $"
-__revision__ = "$Revision: 67568 $"
+__svnid__ = "$Id: ed_main.py 67688 2011-05-03 19:23:35Z CJP $"
+__revision__ = "$Revision: 67688 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -56,12 +56,9 @@ _PSET = profiler.Profile_Set
 #--------------------------------------------------------------------------#
 
 class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
-    """Editras Main Window
-    @todo: modularize the event handling more (pubsub?)
-
-    """
+    """Editras Main Window"""
     # Clipboard ring is limited to 25, why? Because any more is a waste of
-    # memory and an inefficient waste of your time to cyle through.
+    # memory and an inefficient waste of your time to cycle through.
     CLIPBOARD = util.EdClipboard(25)
     PRINTER = None
 
@@ -73,20 +70,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         wx.Frame.__init__(self, parent, id_, title, size=wsize,
                           style=wx.DEFAULT_FRAME_STYLE)
-
-        hint = wx.aui.AUI_MGR_TRANSPARENT_HINT
-        if wx.Platform == '__WXGTK__':
-            # Use venetian blinds style as transparent can cause crashes
-            # on linux when desktop compositing is used.
-            hint = wx.aui.AUI_MGR_VENETIAN_BLINDS_HINT
-
-        self._mgr = wx.aui.AuiManager(flags=wx.aui.AUI_MGR_DEFAULT |
-                                      wx.aui.AUI_MGR_TRANSPARENT_DRAG |
-                                      hint |
-                                      wx.aui.AUI_MGR_ALLOW_ACTIVE_PANE)
-        self._mgr.SetManagedWindow(self)
-        viewmgr.PerspectiveManager.__init__(self, self._mgr, \
-                                            CONFIG['CACHE_DIR'])
+        viewmgr.PerspectiveManager.__init__(self, CONFIG['CACHE_DIR'])
 
         # Setup app icon and title
         util.SetWindowIcon(self)
@@ -111,10 +95,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         #---- Notebook that contains the editing buffers ----#
         self._mpane = ed_mpane.MainPanel(self)
         self.nb = self._mpane.GetWindow()
-        self._mgr.AddPane(self._mpane, wx.aui.AuiPaneInfo(). \
-                          Name("EditPane").Center().Layer(1).Dockable(False). \
-                          CloseButton(False).MaximizeButton(False). \
-                          CaptionVisible(False))
+        self.PanelMgr.AddPane(self._mpane, wx.aui.AuiPaneInfo(). \
+                              Name("EditPane").Center().Layer(1).Dockable(False). \
+                              CloseButton(False).MaximizeButton(False). \
+                              CaptionVisible(False))
         self._mpane.InitCommandBar() # <- required due to nb dependencies...
 
         #---- Command Bar ----#
@@ -299,7 +283,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         # Set Perspective and other UI settings
         self.SetPerspective(_PGET('DEFAULT_VIEW'))
-        self._mgr.Update()
+        self.PanelMgr.Update()
         # TODO: this callback is no longer necessary due to the
         #       profile notifier callbacks.
         ed_msg.PostMessage(ed_msg.EDMSG_DSP_FONT,
@@ -516,13 +500,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         """
         return self._mpane
 
-    def GetFrameManager(self):
-        """Returns the manager for this frame
-        @return: Reference to the AuiMgr of this window
-
-        """
-        return self._mgr
-
     def GetNotebook(self):
         """Get the windows main notebook that contains the editing buffers
         @return: reference to L{extern.flatnotebook.FlatNotebook} instance
@@ -832,14 +809,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @param evt: event that called this handler
 
         """
-        statbar = self.GetStatusBar()
-        if statbar:
-            # The frames Set/PushStatusText methods don't seem to call the
-            # method of the statusbar class instance when setting the text so
-            # get and set the text in the status bar directly so that our
-            # statusbar's overridden settext method gets called
-            statbar.SetStatusText(evt.GetMessage(), evt.GetSection())
-#            self.SetStatusText(evt.GetMessage(), evt.GetSection())
+        self.SetStatusText(evt.GetMessage(), evt.GetSection())
 
     def OnPrint(self, evt):
         """Handles sending the current document to the printer,
@@ -951,7 +921,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self.LOG("[ed_main][info] Saving profile to %s" % ppath)
 
         # Post exit notice to all aui panes
-        panes = self._mgr.GetAllPanes()
+        panes = self.PanelMgr.GetAllPanes()
         exit_evt = ed_event.MainWindowExitEvent(ed_event.edEVT_MAINWINDOW_EXIT,
                                                 wx.ID_ANY)
         for pane in panes:
@@ -1015,14 +985,14 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @param evt: CommandEvent instance
 
         """
-        paneInfo = self._mgr.GetPane("EditPane")
+        paneInfo = self.PanelMgr.GetPane("EditPane")
         if paneInfo.IsMaximized():
-            self._mgr.RestorePane(paneInfo)
+            self.PanelMgr.RestorePane(paneInfo)
             ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_RESTORE, context=self.GetId())
         else:
-            self._mgr.RestoreMaximizedPane()
-            self._mgr.MaximizePane(paneInfo)
-        self._mgr.Update()
+            self.PanelMgr.RestoreMaximizedPane()
+            self.PanelMgr.MaximizePane(paneInfo)
+        self.PanelMgr.Update()
         
     #---- End View Menu Functions ----#
 
@@ -1252,7 +1222,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 return
 
             bmp = wx.ArtProvider.GetBitmap(str(ID_NEW_WINDOW), wx.ART_MENU)
-            self._paneNavi = eclib.AuiPaneNavigator(self, self._mgr, bmp,
+            self._paneNavi = eclib.AuiPaneNavigator(self, self.PanelMgr, bmp,
                                                       _("Aui Pane Navigator"))
             self._paneNavi.SetReturnCode(wx.ID_OK)
             ebmlib.LockCall(self._mlock, self._paneNavi.ShowModal)
@@ -1262,11 +1232,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             self._paneNavi = None
 
             if isinstance(sel, basestring):
-                paneInfo = self._mgr.GetPane(sel)
+                paneInfo = self.PanelMgr.GetPane(sel)
                 if paneInfo.IsOk():
                     if not paneInfo.IsShown():
                         paneInfo.Show()
-                        self._mgr.Update()
+                        self.PanelMgr.Update()
                         # Notify activation if the window supports it
                         if hasattr(paneInfo.window, "OnShowAUIPane"):
                             paneInfo.window.OnShowAUIPane()
@@ -1427,7 +1397,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         elif e_id == ID_INDENT_GUIDES:
             evt.Check(bool(ctrl.GetIndentationGuides()))
         elif e_id == ID_MAXIMIZE_EDITOR:
-            paneInfo = self._mgr.GetPane("EditPane")
+            paneInfo = self.PanelMgr.GetPane("EditPane")
             binder = self.MenuBar.GetKeyBinder()
             binding = binder.GetBinding(ID_MAXIMIZE_EDITOR)
             txt = _("Maximize Editor")
@@ -1512,7 +1482,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         """
         sb = self.GetStatusBar()
-        sb.PushStatusText(txt, field)
+        if sb:
+            sb.PushStatusText(txt, field)
 
     SetStatusText = PushStatusText
 
