@@ -14,8 +14,8 @@ Shelf plugin and control implementation
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_shelf.py 67547 2011-04-19 15:59:41Z CJP $"
-__revision__ = "$Revision: 67547 $"
+__svnid__ = "$Id: ed_shelf.py 67674 2011-05-02 17:35:04Z CJP $"
+__revision__ = "$Revision: 67674 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -91,7 +91,7 @@ class Shelf(plugin.Plugin):
         mgr.AddPane(shelf,
                     wx.aui.AuiPaneInfo().Name(Shelf.SHELF_NAME).\
                             Caption("Shelf").Bottom().Layer(0).\
-                            CloseButton(True).MaximizeButton(False).\
+                            CloseButton(True).MaximizeButton(True).\
                             BestSize(wx.Size(500,250)))
 
         # Hide the pane and let the perspective manager take care of it
