@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 67517 2011-04-16 20:29:35Z CJP $"
-__revision__ = "$Revision: 67517 $"
+__svnid__ = "$Id: ed_stc.py 67648 2011-04-29 03:39:27Z CJP $"
+__revision__ = "$Revision: 67648 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -40,6 +40,7 @@ import ed_mdlg
 import ed_txt
 from ed_keyh import KeyHandler, ViKeyHandler
 import ebmlib
+import ed_thread
 
 #-------------------------------------------------------------------------#
 # Globals
@@ -611,15 +612,19 @@ class EditraStc(ed_basestc.EditraBaseStc):
 
         if not self._backup_done and \
            (not bkupmgr.HasBackup(fname) or bkupmgr.IsBackupNewer(fname)):
-            writer = bkupmgr.GetBackupWriter(self.File)
-            try:
-                writer(self.GetText())
-            except:
-                return
             msg = _("File backup performed: %s") % fname
-            nevt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(),
-                                        msg, ed_glob.SB_INFO)
-            wx.PostEvent(self.GetTopLevelParent(), nevt)
+            idval = self.Id
+            target = self.TopLevelParent
+            def BackupJob(fobj, text):
+                writer = bkupmgr.GetBackupWriter(fobj)
+                try:
+                    writer(text)
+                except Exception, msg:
+                    return
+                nevt = ed_event.StatusEvent(ed_event.edEVT_STATUS, idval,
+                                            msg, ed_glob.SB_INFO)
+                wx.PostEvent(target, nevt)
+            ed_thread.EdThreadPool().QueueJob(BackupJob, self.File, self.GetText())
             self._backup_done = True
 
     def OnModified(self, evt):
@@ -834,6 +839,7 @@ class EditraStc(ed_basestc.EditraBaseStc):
 #                sb.ProcessPendingEvents()
                 self.SetReadOnly(False)
                 self.AppendText(evt.GetValue())
+                self.SetSavePoint()
                 self.SetReadOnly(True)
                 # wx.GetApp().Yield(True) # Too slow on windows...
         elif evt.GetState() == ed_txt.FL_STATE_END:
