@@ -20,8 +20,8 @@ happen during run time.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 66449 2010-12-26 05:09:16Z CJP $"
-__revision__ = "$Revision: 66449 $"
+__svnid__ = "$Id: profiler.py 67571 2011-04-22 01:10:57Z CJP $"
+__revision__ = "$Revision: 67571 $"
 
 #--------------------------------------------------------------------------#
 # Imports
@@ -281,30 +281,9 @@ TheProfile = Profile()
 
 #-----------------------------------------------------------------------------#
 # Profile convenience functions
-def Profile_Del(item):
-    """Removes an item from the profile
-    @param item: items key name
-
-    """
-    TheProfile.DeleteItem(item)
-
-def Profile_Get(index, fmt=None, default=None):
-    """Convenience for Profile().Get()
-    @param index: profile index to retrieve
-    @keyword fmt: format to get value as
-    @keyword default: default value to return if not found
-
-    """
-    return TheProfile.Get(index, fmt, default)
-
-def Profile_Set(index, val, fmt=None):
-    """Convenience for Profile().Set()
-    @param index: profile index to set
-    @param val: value to set index to
-    @keyword fmt: format to convert object from
-
-    """
-    return TheProfile.Set(index, val, fmt)
+Profile_Del  = TheProfile.DeleteItem
+Profile_Get = TheProfile.Get
+Profile_Set = TheProfile.Set
 
 def _FromObject(val, fmt):
     """Convert the given value to a to a profile compatible value
@@ -356,17 +335,6 @@ def _ToObject(index, val, fmt):
     return rval
 
 #---- Begin Function Definitions ----#
-def AddFileHistoryToProfile(file_history):
-    """Manages work of adding a file from the profile in order
-    to allow the top files from the history to be available
-    the next time the user opens the program.
-    @param file_history: add saved files to history list
-
-    """
-    files = list()
-    for fnum in xrange(file_history.GetNoHistoryFiles()):
-        files.append(file_history.GetHistoryFile(fnum))
-    Profile_Set('FHIST', files)
 
 def CalcVersionValue(ver_str="0.0.0"):
     """Calculates a version value from the provided dot-formated string
@@ -399,12 +367,8 @@ def GetLoader():
            should be.
 
     """
-    cbase = CONFIG['CONFIG_BASE']
-    if cbase is None:
-        cbase = wx.StandardPaths_Get().GetUserDataDir()
-
+    cbase = util.GetUserConfigBase()
     loader = os.path.join(cbase, u"profiles", u".loader2")
-
     return loader
 
 def GetProfileStr():
